\name{summary.rvbm}
\alias{summary.rvbm}
\alias{print.summary.rvbm}
\title{Summary Statistics of Variational Bayesian Multiclass Probit Regression}

\description{
  This method gives summary statistics of
  the Gaussian process model created with \code{rvbm}.
}

\usage{
\method{summary}{rvbm}(object, \dots)
}

\arguments{
  \item{object}{An S3 object that inherits from the class \code{rvbm}.}
  \item{\dots}{Not used.}
}

\value{
  An S3 object of type \code{summary.rvbm} that contains the following:\cr
  \itemize{
    \item{Kc: }{Number of response categories.}
    \item{covParams: }{Estimated theta covariance parameters.}
    \item{predLik: }{Predictive log likelihood of the fitted model.}
    \item{predError: }{Percentage of the prediction errors.}
    \item{predClass: }{Predicted class membership of the test data.}
  }
}
\author{
  Chi Yau\cr
  \email{chi.yau@r-tutor.com}
}
\note{
  This replaces the \code{covParams}, \code{predLik},
  \code{predError}, and \code{predClass} methods in \code{vbmp}.
}
\seealso{\code{\link{rvbm}}, \code{vbmp}}

\examples{
\dontrun{
library(rpud)

x <- rvbm.sample.train$X
y <- rvbm.sample.train$t.class
model.rvbm <- rvbm( 
    x, y, x, y,
    theta = rep(1, ncol(x)), 
    control = list(
            sKernelType="gaussian", 
            bThetaEstimate=TRUE, 
            bMonitor=TRUE,
            maxIts=12,
            InfoLevel=1) 
)

summary(model.rvbm)

}}
\keyword{neural}% at least one, from doc/KEYWORDS
\keyword{classif}% __ONLY ONE__ keyword per line
\keyword{nonlinear}% __ONLY ONE__ keyword per line

